@@ -5,8 +5,9 @@ import enum
 import typing as t
 
 Orderable = t.Union[int, float]
+BasicType = t.Union[bool, str, Orderable]
 Date = t.Union[datetime.date, datetime.datetime]
-ValueType = t.Union[bool, str, Orderable, Date]
+ValueType = t.Union[BasicType, Date]
 
 
 class FilterType(enum.Enum):
@@ -44,8 +45,9 @@ class Filter:
   filter: FilterMode
   value: t.Optional[ValueType]
 
-  def to_query_parameter(self) -> t.Tuple[str, str]:
+  def to_query_parameter(self) -> t.Tuple[str, t.Optional[str]]:
     key = f'filter__{self.field}__{self.filter.name}'
+    value: t.Optional[str]
     if isinstance(self.value, datetime.datetime):
       value = self.value.strftime('%Y-%m-%dT%H:%M:%S%z')
     elif isinstance(self.value, datetime.date):
@@ -53,7 +55,7 @@ class Filter:
     elif self.value is None:
       value = None
     else:
-      value = self.value
+      value = str(self.value)
     return (key, value)
 
 
@@ -65,65 +67,65 @@ class Column:
   def __init__(self, name: str) -> None:
     self._name = name
 
-  def equal(self, value: ValueType) -> None:
+  def equal(self, value: ValueType) -> Filter:
     return Filter(self._name, FilterMode.equal, value)
 
-  def not_equal(self, value: ValueType) -> None:
+  def not_equal(self, value: ValueType) -> Filter:
     return Filter(self._name, FilterMode.not_equal, value)
 
-  def filename_contains(self, value: str) -> None:
+  def filename_contains(self, value: str) -> Filter:
     return Filter(self._name, FilterMode.filename_contains, value)
 
-  def contains(self, value: str) -> None:
+  def contains(self, value: str) -> Filter:
     return Filter(self._name, FilterMode.contains, value)
 
-  def contains_not(self, value: str) -> None:
+  def contains_not(self, value: str) -> Filter:
     return Filter(self._name, FilterMode.contains_not, value)
 
-  def higher_than(self, value: Orderable) -> None:
+  def higher_than(self, value: Orderable) -> Filter:
     return Filter(self._name, FilterMode.higher_than, value)
 
-  def lower_than(self, value: Orderable) -> None:
+  def lower_than(self, value: Orderable) -> Filter:
     return Filter(self._name, FilterMode.lower_than, value)
 
-  def date_equal(self, value: Date) -> None:
+  def date_equal(self, value: Date) -> Filter:
     return Filter(self._name, FilterMode.date_equal, value)
 
-  def date_before(self, value: Date) -> None:
+  def date_before(self, value: Date) -> Filter:
     return Filter(self._name, FilterMode.date_before, value)
 
-  def date_after(self, value: Date) -> None:
+  def date_after(self, value: Date) -> Filter:
     return Filter(self._name, FilterMode.date_after, value)
 
-  def date_not_equal(self, value: Date) -> None:
+  def date_not_equal(self, value: Date) -> Filter:
     return Filter(self._name, FilterMode.date_not_equal, value)
 
-  def date_equals_today(self) -> None:
+  def date_equals_today(self) -> Filter:
     return Filter(self._name, FilterMode.date_equals_today, None)
 
-  def date_equals_month(self, month: int) -> None:
+  def date_equals_month(self, month: int) -> Filter:
     return Filter(self._name, FilterMode.date_equals_month, month)
 
-  def date_equals_year(self, year: int) -> None:
+  def date_equals_year(self, year: int) -> Filter:
     return Filter(self._name, FilterMode.date_equals_year, year)
 
-  def single_select_equal(self, value: str) -> None:
+  def single_select_equal(self, value: str) -> Filter:
     return Filter(self._name, FilterMode.single_select_equal, value)
 
-  def single_select_not_equal(self, value: str) -> None:
+  def single_select_not_equal(self, value: str) -> Filter:
     return Filter(self._name, FilterMode.single_select_not_equal, value)
 
-  def link_row_has(self, value: int) -> None:
+  def link_row_has(self, value: int) -> Filter:
     return Filter(self._name, FilterMode.link_row_has, value)
 
-  def link_row_has_not(self, value: int) -> None:
+  def link_row_has_not(self, value: int) -> Filter:
     return Filter(self._name, FilterMode.link_row_has_not, value)
 
-  # def boolean(self, value: ValueType) -> None:
+  # def boolean(self, value: ValueType) -> Filter:
   #   return Filter(self._name, FilterMode.boolean, value)
 
-  def empty(self) -> None:
+  def empty(self) -> Filter:
     return Filter(self._name, FilterMode.empty, None)
 
-  def not_empty(self) -> None:
+  def not_empty(self) -> Filter:
     return Filter(self._name, FilterMode.not_empty, None)
