@@ -2,7 +2,7 @@
 from .column import Column, ForeignKey
 from .database import Database
 from .exc import BaserowOrmException, NoRowReturned
-from .mapping import DatabaseMapping
+from .mapping import DatabaseMapping, generate_mapping
 from .model import Model
 
 __all__ = [
@@ -12,5 +12,6 @@ __all__ = [
   'BaserowOrmException',
   'NoRowReturned',
   'DatabaseMapping',
+  'generate_mapping',
   'Model'
 ]
